/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef _imageprovider_
#define _imageprovider_

namespace AriaMaestosa {
	
class Image; // forward
class Drawable;

class ImagesStruct {
public:
    // note display
    Image* noteTrackImg;
    Image* noteTrackBackgImg;
    
    Drawable* noteTrackDrawable;
    Drawable* noteTrackBackgDrawable;
    
    // scrollbar
    Image* sbArrowImg;
    Image* sbArrowDownImg;
    Image* sbBackgImg;
    Image* sbBarImg;
    
    Drawable* sbArrowDrawable;
    Drawable* sbBackgDrawable;
    Drawable* sbBarDrawable;
    
    // track UI
    Image* cornerImg;
    Image* borderImg;
    Image* whiteCornerImg;
    Image* whiteBorderImg;
    
    Drawable* cornerDrawable;
    Drawable* borderDrawable;
    Drawable* whiteCornerDrawable;
    Drawable* whiteBorderDrawable;
    
    // collapseDrawable
    Image* collapseImg;
    Image* expandImg;
    Image* dockTrackImg;
    
    Drawable* collapseDrawable;
    Drawable* dockTrackDrawable;
    
    // mute
    Image* muteOnImg;
    Image* muteOffImg;
    
    Drawable* muteDrawable;
    
    // combo box
    Image* comboBorderImg;
    Image* comboBodyImg;
    Image* comboSelectImg;
    
    Drawable* comboBorderDrawable;
    Drawable* comboBodyDrawable;
    Drawable* comboSelectDrawable;
    
    // Editor modes
    Image* guitar_viewImg;
    Image* keyboard_viewImg;
    Image* score_viewImg;
    Image* drum_viewImg;
    Image* controller_viewImg;
    
    Drawable* guitar_view;
    Drawable* keyboard_view;
    Drawable* score_view;
    Drawable* drum_view;
    Drawable* controller_view;
    
    Image* tabBorderImg;
    Image* tabImg;
    
    Drawable* tabBorderDrawable;
    Drawable* tabDrawable;
	
	// score
	Image* keyGImg;
    Drawable* keyG;
	
	Image* noteClosedImg;
    Drawable* noteClosed;
	
	Image* noteOpenImg;
    Drawable* noteOpen;
	
	Image* noteTailImg;
    Drawable* noteTail;
};

namespace ImageProvider {
    
    void loadImages();
    void unloadImages();
    ImagesStruct* getImages();
    bool imagesLoaded();
}

#ifndef _NO_SPRITE_SHORTCUTS_
#define sbArrowDrawable ImageProvider::getImages()->sbArrowDrawable
#define sbBackgDrawable ImageProvider::getImages()->sbBackgDrawable
#define sbBarDrawable ImageProvider::getImages()->sbBarDrawable

#define sbArrowDownImg ImageProvider::getImages()->sbArrowDownImg
#define sbArrowImg ImageProvider::getImages()->sbArrowImg

#define tabBorderDrawable ImageProvider::getImages()->tabBorderDrawable
#define tabDrawable ImageProvider::getImages()->tabDrawable

#define noteTrackDrawable ImageProvider::getImages()->noteTrackDrawable
#define noteTrackBackgDrawable ImageProvider::getImages()->noteTrackBackgDrawable

#define cornerDrawable ImageProvider::getImages()->cornerDrawable
#define borderDrawable ImageProvider::getImages()->borderDrawable
#define whiteCornerDrawable ImageProvider::getImages()->whiteCornerDrawable
#define whiteBorderDrawable ImageProvider::getImages()->whiteBorderDrawable

#define muteOnImg ImageProvider::getImages()->muteOnImg
#define muteOffImg ImageProvider::getImages()->muteOffImg
#define collapseImg ImageProvider::getImages()->collapseImg
#define expandImg ImageProvider::getImages()->expandImg

#define comboSelectDrawable ImageProvider::getImages()->comboSelectDrawable
#define comboBodyDrawable ImageProvider::getImages()->comboBodyDrawable
#define comboBorderDrawable ImageProvider::getImages()->comboBorderDrawable

#define collapseDrawable ImageProvider::getImages()->collapseDrawable
#define muteDrawable ImageProvider::getImages()->muteDrawable
#define dockTrackDrawable ImageProvider::getImages()->dockTrackDrawable

#define guitar_view ImageProvider::getImages()->guitar_view
#define keyboard_view ImageProvider::getImages()->keyboard_view
#define score_view ImageProvider::getImages()->score_view
#define drum_view ImageProvider::getImages()->drum_view
#define controller_view ImageProvider::getImages()->controller_view

#define keyG ImageProvider::getImages()->keyG
#define noteClosed ImageProvider::getImages()->noteClosed
#define noteOpen ImageProvider::getImages()->noteOpen
#define noteTail ImageProvider::getImages()->noteTail

#define imagesLoaded() ImageProvider::imagesLoaded()

#endif

}

#endif
